@@ -7,6 +7,8 @@ from copy import deepcopy
 import inspect
 import types
 
+from .context import Context
+from .parser import Argument, translate_underscores
 from .util import six
 
 if six.PY3:
@@ -14,9 +16,6 @@ if six.PY3:
 else:
     from itertools import izip_longest as zip_longest
 
-from .context import Context
-from .parser import Argument, translate_underscores
-
 
 #: Sentinel object representing a truly blank value (vs ``None``).
 NO_DEFAULT = object()
@@ -37,6 +36,7 @@ class Task(object):
 
     .. versionadded:: 1.0
     """
+
     # TODO: store these kwarg defaults central, refer to those values both here
     # and in @task.
     # TODO: allow central per-session / per-taskmodule control over some of
@@ -44,7 +44,8 @@ class Task(object):
     # NOTE: we shadow __builtins__.help here on purpose - obfuscating to avoid
     # it feels bad, given the builtin will never actually be in play anywhere
     # except a debug shell whose frame is exactly inside this class.
-    def __init__(self,
+    def __init__(
+        self,
         body,
         name=None,
         aliases=(),
@@ -63,9 +64,9 @@ class Task(object):
         self.body = body
         # Copy a bunch of special properties from the body for the benefit of
         # Sphinx autodoc or other introspectors.
-        self.__doc__ = getattr(body, '__doc__', '')
-        self.__name__ = getattr(body, '__name__', '')
-        self.__module__ = getattr(body, '__module__', '')
+        self.__doc__ = getattr(body, "__doc__", "")
+        self.__name__ = getattr(body, "__name__", "")
+        self.__module__ = getattr(body, "__module__", "")
         # Default name, alternate names, and whether it should act as the
         # default for its parent collection
         self._name = name
@@ -92,7 +93,7 @@ class Task(object):
     def __repr__(self):
         aliases = ""
         if self.aliases:
-            aliases = " ({})".format(', '.join(self.aliases))
+            aliases = " ({})".format(", ".join(self.aliases))
         return "<Task {!r}{}>".format(self.name, aliases)
 
     def __eq__(self, other):
@@ -105,10 +106,9 @@ class Task(object):
             return True
         else:
             try:
-                return (
-                    six.get_function_code(self.body) ==
-                    six.get_function_code(other.body)
-                )
+                return six.get_function_code(
+                    self.body
+                ) == six.get_function_code(other.body)
             except AttributeError:
                 return False
 
@@ -169,7 +169,7 @@ class Task(object):
         # value will be automatically considered positional.
         if positional is None:
             positional = []
-            for name in args: # Go in defined order, not dict "order"
+            for name in args:  # Go in defined order, not dict "order"
                 default = spec_dict[name]
                 if default is NO_DEFAULT:
                     positional.append(name)
@@ -178,23 +178,23 @@ class Task(object):
     def arg_opts(self, name, default, taken_names):
         opts = {}
         # Whether it's positional or not
-        opts['positional'] = name in self.positional
+        opts["positional"] = name in self.positional
         # Whether it is a value-optional flag
-        opts['optional'] = name in self.optional
+        opts["optional"] = name in self.optional
         # Whether it should be of an iterable (list) kind
         if name in self.iterable:
-            opts['kind'] = list
+            opts["kind"] = list
             # If user gave a non-None default, hopefully they know better
             # than us what they want here (and hopefully it offers the list
             # protocol...) - otherwise supply useful default
-            opts['default'] = default if default is not None else []
+            opts["default"] = default if default is not None else []
         # Whether it should increment its value or not
         if name in self.incrementable:
-            opts['incrementable'] = True
+            opts["incrementable"] = True
         # Argument name(s) (replace w/ dashed version if underscores present,
         # and move the underscored version to be the attr_name instead.)
-        if '_' in name:
-            opts['attr_name'] = name
+        if "_" in name:
+            opts["attr_name"] = name
             name = translate_underscores(name)
         names = [name]
         if self.auto_shortflags:
@@ -203,7 +203,7 @@ class Task(object):
                 if not (char == name or char in taken_names):
                     names.append(char)
                     break
-        opts['names'] = names
+        opts["names"] = names
         # Handle default value & kind if possible
         if default not in (None, NO_DEFAULT):
             # TODO: allow setting 'kind' explicitly.
@@ -211,12 +211,12 @@ class Task(object):
             # bool; that results in a nonsensical Argument which gives the
             # parser grief in a few ways.
             kind = type(default)
-            if not (opts['optional'] and kind is bool):
-                opts['kind'] = kind
-            opts['default'] = default
+            if not (opts["optional"] and kind is bool):
+                opts["kind"] = kind
+            opts["default"] = default
         # Help
         if name in self.help:
-            opts['help'] = self.help[name]
+            opts["help"] = self.help[name]
         return opts
 
     def get_arguments(self):
@@ -296,45 +296,46 @@ def task(*args, **kwargs):
     * ``autoprint``: Boolean determining whether to automatically print this
       task's return value to standard output when invoked directly via the CLI.
       Defaults to False.
+    * ``klass``: Class to instantiate/return. Defaults to `.Task`.
 
     If any non-keyword arguments are given, they are taken as the value of the
     ``pre`` kwarg for convenience's sake. (It is an error to give both
     ``*args`` and ``pre`` at the same time.)
 
     .. versionadded:: 1.0
+    .. versionchanged:: 1.1
+        Added the ``klass`` keyword argument.
     """
+    klass = kwargs.pop("klass", Task)
     # @task -- no options were (probably) given.
     if len(args) == 1 and callable(args[0]) and not isinstance(args[0], Task):
-        return Task(args[0], **kwargs)
+        return klass(args[0], **kwargs)
     # @task(pre, tasks, here)
     if args:
-        if 'pre' in kwargs:
+        if "pre" in kwargs:
             raise TypeError(
                 "May not give *args and 'pre' kwarg simultaneously!"
             )
-        kwargs['pre'] = args
+        kwargs["pre"] = args
     # @task(options)
-    # TODO: pull in centrally defined defaults here (see Task)
-    # TODO: clean up all of the values which are iterables, some are tuple and
-    # some are None->list, ugh
-    name = kwargs.pop('name', None)
-    aliases = kwargs.pop('aliases', ())
-    positional = kwargs.pop('positional', None)
-    optional = tuple(kwargs.pop('optional', ()))
-    iterable = kwargs.pop('iterable', None)
-    incrementable = kwargs.pop('incrementable', None)
-    default = kwargs.pop('default', False)
-    auto_shortflags = kwargs.pop('auto_shortflags', True)
-    help = kwargs.pop('help', {})
-    pre = kwargs.pop('pre', [])
-    post = kwargs.pop('post', [])
-    autoprint = kwargs.pop('autoprint', False)
-    # Handle unknown kwargs
-    if kwargs:
-        kwarg = (" unknown kwargs {!r}".format(kwargs)) if kwargs else ""
-        raise TypeError("@task was called with" + kwarg)
+    # TODO: why the heck did we originally do this in this manner instead of
+    # simply delegating to Task?! Let's just remove all this sometime & see
+    # what, if anything, breaks.
+    name = kwargs.pop("name", None)
+    aliases = kwargs.pop("aliases", ())
+    positional = kwargs.pop("positional", None)
+    optional = tuple(kwargs.pop("optional", ()))
+    iterable = kwargs.pop("iterable", None)
+    incrementable = kwargs.pop("incrementable", None)
+    default = kwargs.pop("default", False)
+    auto_shortflags = kwargs.pop("auto_shortflags", True)
+    help = kwargs.pop("help", {})
+    pre = kwargs.pop("pre", [])
+    post = kwargs.pop("post", [])
+    autoprint = kwargs.pop("autoprint", False)
+
     def inner(obj):
-        obj = Task(
+        obj = klass(
             obj,
             name=name,
             aliases=aliases,
@@ -348,8 +349,11 @@ def task(*args, **kwargs):
             pre=pre,
             post=post,
             autoprint=autoprint,
+            # Pass in any remaining kwargs as-is.
+            **kwargs
         )
         return obj
+
     return inner
 
 
@@ -363,13 +367,8 @@ class Call(object):
 
     .. versionadded:: 1.0
     """
-    def __init__(
-        self,
-        task,
-        called_as=None,
-        args=None,
-        kwargs=None,
-    ):
+
+    def __init__(self, task, called_as=None, args=None, kwargs=None):
         """
         Create a new `.Call` object.
 
@@ -402,8 +401,12 @@ class Call(object):
         aka = ""
         if self.called_as is not None and self.called_as != self.task.name:
             aka = " (called as: {!r})".format(self.called_as)
-        return "<Call {!r}{}, args: {!r}, kwargs: {!r}>".format(
-            self.task.name, aka, self.args, self.kwargs
+        return "<{} {!r}{}, args: {!r}, kwargs: {!r}>".format(
+            self.__class__.__name__,
+            self.task.name,
+            aka,
+            self.args,
+            self.kwargs,
         )
 
     def __eq__(self, other):
@@ -424,23 +427,48 @@ class Call(object):
         """
         return Context(config=config)
 
-    def clone(self, into=None):
+    def clone_data(self):
         """
-        Return a standalone copy of this Call.
+        Return keyword args suitable for cloning this call into another.
 
-        Useful when parameterizing task executions.
-
-        :param into: A subclass to generate instead of the current class.
-
-        .. versionadded:: 1.0
+        .. versionadded:: 1.1
         """
-        return (into if into is not None else self.__class__)(
+        return dict(
             task=self.task,
             called_as=self.called_as,
             args=deepcopy(self.args),
             kwargs=deepcopy(self.kwargs),
         )
 
+    def clone(self, into=None, with_=None):
+        """
+        Return a standalone copy of this Call.
+
+        Useful when parameterizing task executions.
+
+        :param into:
+            A subclass to generate instead of the current class. Optional.
+
+        :param dict with_:
+            A dict of additional keyword arguments to use when creating the new
+            clone; typically used when cloning ``into`` a subclass that has
+            extra args on top of the base class. Optional.
+
+            .. note::
+                This dict is used to ``.update()`` the original object's data
+                (the return value from its `clone_data`), so in the event of
+                a conflict, values in ``with_`` will win out.
+
+        .. versionadded:: 1.0
+        .. versionchanged:: 1.1
+            Added the ``with_`` kwarg.
+        """
+        klass = into if into is not None else self.__class__
+        data = self.clone_data()
+        if with_ is not None:
+            data.update(with_)
+        return klass(**data)
+
 
 def call(task, *args, **kwargs):
     """
